@@ -45,6 +45,7 @@ def build_index(dirbook) :
     content +=("  <title>Novels</title>\n")
     content +=("</head>\n")
     content +=("<body style=\"background-color: #212121;color: #B5B5B5;\">\n")
+    content += '<div align="center" style="vertical-align:bottom">' + "\n"
     content +=("<table border=1 style=\"border-collapse:collapse;\">\n")
     tmstr = strftime("%H:%M",localtime())
     content +=("<tr style=\"background-color:{};\"><td><a href=\".\">{}({})</a></td><td></td></tr>\n".format("#374FB2","Index",tmstr))
@@ -77,6 +78,7 @@ def build_index(dirbook) :
                     content +=(ln+"</tr>\n")
                     cnt += 1
     content +=("</table>\n")
+    content +=("</div>\n")
     content +=("</html>\n")
     with open(os.path.join(dirbook,"index.html"),"w",encoding="UTF-8") as fw  :
         fw.write(content)
@@ -295,8 +297,9 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False,force=0,root=
         rtext += "</html>\n"
         with open(os.path.join(tgtdir,title, cname),"w",encoding="UTF-8") as f :
             f.write(rtext)
-        with open(os.path.join(tgtdir,title, "downloaded.txt"),"a",encoding="UTF-8") as f :
-            f.write(cname+"\n")
+        if context != "PLACEHOLDER" :
+            with open(os.path.join(tgtdir,title, "downloaded.txt"),"a",encoding="UTF-8") as f :
+                f.write(cname+"\n")
         if cname not in downloaded :
             with open(os.path.join(tgtdir,title, "index.html"),"a",encoding="UTF-8") as f :
                 hcontent = "<tr><td><a href=\"{}\">{}</a></td></tr>".format(cname,chapter) + "\n"
